pub struct DataChannelMessage {
pub association_handle: usize,
pub stream_id: u16,
pub ppi: PayloadProtocolIdentifier,
pub payload: BytesMut,
pub negotiated: bool,
}Expand description
DataChannelMessage is used to data sent over SCTP
Fields
association_handle: usizeIdentifies the SCTP association this message belongs to.
stream_id: u16The SCTP stream the message arrived on or should be sent on.
ppi: PayloadProtocolIdentifierThe payload protocol identifier, which distinguishes DCEP control messages from string and binary user data.
payload: BytesMutThe message bytes.
negotiated: boolMarks a DATA_CHANNEL_OPEN that belongs to an out-of-band negotiated
channel (W3C WebRTC RTCDataChannelInit.negotiated). Such a message is
only used to open and configure the local SCTP stream and must not be
transmitted to the peer, which already created its own channel with the
pre-agreed stream id. Ignored for every other message.